hasNextResult property
bool
get
hasNextResult
Returns true if there is more data to fetch beyond the data
contained in this response. If true, the request for the next page of
data can be obtained with .requestForNextResult.
Implementation
bool get hasNextResult {
return requestForNextResult != null;
}